SSHHostKey class abstract

Represents an SSH public host key or user public key in SSH wire format.

Implementers

Constructors

SSHHostKey()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Uint8List
Encodes the host key to SSH binary wire format.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getType(Uint8List encodedHostKey) String
Extracts the key type identifier (e.g., ssh-rsa, ssh-ed25519, ecdsa-sha2-nistp256) from an encodedHostKey binary blob.