OpenSSHEd25519KeyPair class
An Ed25519 private/public key pair encoded in OpenSSH format.
- Mixed-in types
Constructors
- OpenSSHEd25519KeyPair(Uint8List publicKey, Uint8List privateKey, String comment)
-
Creates an OpenSSHEd25519KeyPair with
publicKey,privateKey, andcomment. - OpenSSHEd25519KeyPair.readFrom(SSHMessageReader reader)
-
Reads an OpenSSHEd25519KeyPair from an OpenSSH binary
reader.factory
Properties
- comment → String
-
In-memory key pairs do not use comment probing by default.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The algorithm name used when serializing the key (e.g.,
ssh-rsa,ssh-ed25519,ecdsa-sha2-nistp256).final - privateKey → Uint8List
-
64-byte Ed25519 private key seed / expanded key.
final
- publicKey → Uint8List
-
32-byte Ed25519 public key.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldProbe → bool
-
In-memory key pairs do not require probing by default since signing is
local and synchronous.
no setterinherited
- type → String
-
The signature algorithm name used when signing challenges.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sign(
Uint8List data) → SSHEd25519Signature -
Synchronously signs binary
datawith this private key.override -
toPem(
) → String -
Encodes this key pair into PEM string format.
inherited
-
toPublicKey(
) → SSHHostKey -
Exports the public key portion of this key pair as an SSHHostKey.
override
-
toString(
) → String -
A string representation of this object.
override
-
writeTo(
SSHMessageWriter writer) → void -
Serializes private key components into
writer.override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited