Mixin for OpenSSH format key pair implementations.
- Implemented types
- Implementers
Constructors
Properties
- comment → String?
-
In-memory key pairs do not use comment probing by default.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The algorithm name used when serializing the key (e.g.,
ssh-rsa,ssh-ed25519,ecdsa-sha2-nistp256).no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldProbe → bool
-
In-memory key pairs do not require probing by default since signing is
local and synchronous.
no setteroverride
- type → String
-
The signature algorithm name used when signing challenges.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sign(
Uint8List data) → SSHSignature -
Synchronously signs binary
datawith this private key.inherited -
toPem(
) → String -
Encodes this key pair into PEM string format.
override
-
toPublicKey(
) → SSHHostKey -
Exports the public key portion of this key pair as an SSHHostKey.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writeTo(
SSHMessageWriter writer) → void -
Serializes private key components into
writer.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited